@@ -13,12 +13,12 @@
 #include "utils.h"
 
 #include <Akonadi/Item>
+#include <Akonadi/TagCache>
 
 #include "calendarsupport_debug.h"
 #include <KConfig>
 #include <KConfigGroup>
 #include <KWordWrap>
-#include <kcalendarcore_version.h>
 
 #include <KLocalizedString>
 #include <QAbstractTextDocumentLayout>
@@ -268,18 +268,13 @@ void CalPrintPluginBase::setColorsByIncidenceCategory(QPainter &p, const KCalend
 
 QColor CalPrintPluginBase::categoryColor(const QStringList &categories) const
 {
-    if (categories.isEmpty()) {
-        return KCalPrefs::instance()->unsetCategoryColor();
-    }
     // FIXME: Correctly treat events with multiple categories
-    const QString cat = categories.at(0);
     QColor bgColor;
-    if (cat.isEmpty()) {
-        bgColor = KCalPrefs::instance()->unsetCategoryColor();
-    } else {
-        bgColor = KCalPrefs::instance()->categoryColor(cat);
+    if (!categories.isEmpty()) {
+        bgColor = Akonadi::TagCache::instance()->tagColor(categories.at(0));
     }
-    return bgColor;
+
+    return bgColor.isValid() ? bgColor : KCalPrefs::instance()->unsetCategoryColor();
 }
 
 QColor CalPrintPluginBase::categoryBgColor(const KCalendarCore::Incidence::Ptr &incidence) const
@@ -1240,10 +1235,10 @@ public:
     }
 
     MonthEventStruct(const QDateTime &s, const QDateTime &e, const KCalendarCore::Event::Ptr &ev)
+        : start(s)
+        , end(e)
+        , event(ev)
     {
-        event = ev;
-        start = s;
-        end = e;
         if (event->allDay()) {
             start = QDateTime(start.date(), QTime(0, 0, 0));
             end = QDateTime(end.date().addDays(1), QTime(0, 0, 0)).addSecs(-1);
@@ -1783,11 +1778,7 @@ void CalPrintPluginBase::drawTodo(int &count,
     for (const KCalendarCore::Todo::Ptr &todo : std::as_const(t)) {
         tl.append(todo);
     }
-#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 95, 0)
-    KCalendarCore::Todo::List sl = mCalendar->sortTodos(tl, sortField, sortDir);
-#else
     KCalendarCore::Todo::List sl = mCalendar->sortTodos(std::move(tl), sortField, sortDir);
-#endif
 #endif
 
     int subcount = 0;
